Module pattern_filter

Module pattern_filter 

Enums

FilterResult
StringOrRegex
StringOrRegexMatchKind

Functions

filter
id is the raw path of file used for regex testing Using FilterResult rather than bool for complicated scenario, e.g. If you have only one filter, just use FilterResult#inner to determine if the id is matched, for multiple filters, you should use FilterResult to determine if the id is matched. See doc of FilterResult
filter_code
Same as above but for code
normalize_path