Enums
Functions
- filter
idis the raw path of file used forregextesting UsingFilterResultrather thanboolfor complicated scenario, e.g. If you have only one filter, just useFilterResult#innerto determine if theidis matched, for multiple filters, you should useFilterResultto determine if theidis matched. See doc of FilterResult- filter_
code - Same as above but for
code - normalize_
path